==> RGtk2_2.8.6.tar.gz: RGtk2/R/atkEnumDefs.R <==
AtkRole<-c("invalid" = 0,
	"accel-label" = 1,
	"alert" = 2,
	"animation" = 3,
	"arrow" = 4,
	"calendar" = 5,
	"canvas" = 6,
	"check-box" = 7,
	"check-menu-item" = 8,
	"color-chooser" = 9,
	"column-header" = 10,
	"combo-box" = 11,
	"date-editor" = 12,
	"desktop-icon" = 13,
	"desktop-frame" = 14,
	"dial" = 15,
	"dialog" = 16,
	"directory-pane" = 17,
	"drawing-area" = 18,
	"file-chooser" = 19,
	"filler" = 20,
	"font-chooser" = 21,
	"frame" = 22,
	"glass-pane" = 23,
	"html-container" = 24,
	"icon" = 25,
	"image" = 26,
	"internal-frame" = 27,
	"label" = 28,
	"layered-pane" = 29,
	"list" = 30,
	"list-item" = 31,
	"menu" = 32,
	"menu-bar" = 33,
	"menu-item" = 34,
	"option-pane" = 35,
	"page-tab" = 36,
	"page-tab-list" = 37,
	"panel" = 38,
	"password-text" = 39,
	"popup-menu" = 40,
	"progress-bar" = 41,
	"push-button" = 42,
	"radio-button" = 43,
	"radio-menu-item" = 44,
	"root-pane" = 45,
	"row-header" = 46,
	"scroll-bar" = 47,
	"scroll-pane" = 48,
	"separator" = 49,
	"slider" = 50,
	"split-pane" = 51,
	"spin-button" = 52,
	"statusbar" = 53,
	"table" = 54,
	"table-cell" = 55,
	"table-column-header" = 56,
	"table-row-header" = 57,
	"tear-off-menu-item" = 58,
	"terminal" = 59,
	"text" = 60,
	"toggle-button" = 61,
	"tool-bar" = 62,
	"tool-tip" = 63,
	"tree" = 64,
	"tree-table" = 65,
	"unknown" = 66,
	"viewport" = 67,
	"window" = 68,
	"header" = 69,
	"footer" = 70,
	"paragraph" = 71,
	"ruler" = 72,
	"application" = 73,
	"autocomplete" = 74,
	"editbar" = 75,
	"embedded" = 76,
	"last-defined" = 77)
storage.mode(AtkRole) <- 'integer'
class(AtkRole) <- 'enums' 

AtkLayer<-c("invalid" = 0,
	"background" = 1,
	"canvas" = 2,
	"widget" = 3,
	"mdi" = 4,
	"popup" = 5,
	"overlay" = 6,
	"window" = 7)
storage.mode(AtkLayer) <- 'integer'
class(AtkLayer) <- 'enums' 

AtkRelationType<-c("null" = 0,
	"controlled-by" = 1,
	"controller-for" = 2,
	"label-for" = 3,
	"labelled-by" = 4,
	"member-of" = 5,
	"node-child-of" = 6,
	"flows-to" = 7,
	"flows-from" = 8,
	"subwindow-of" = 9,
	"embeds" = 10,
	"embedded-by" = 11,
	"popup-for" = 12,
	"parent-window-of" = 13,
	"last-defined" = 14)
storage.mode(AtkRelationType) <- 'integer'
class(AtkRelationType) <- 'enums' 

AtkStateType<-c("invalid" = 0,
	"active" = 1,
	"armed" = 2,
	"busy" = 3,
	"checked" = 4,
	"defunct" = 5,
	"editable" = 6,
	"enabled" = 7,
	"expandable" = 8,
	"expanded" = 9,
	"focusable" = 10,
	"focused" = 11,
	"horizontal" = 12,
	"iconified" = 13,
	"modal" = 14,
	"multi-line" = 15,
	"multiselectable" = 16,
	"opaque" = 17,
	"pressed" = 18,
	"resizable" = 19,
	"selectable" = 20,
	"selected" = 21,
	"sensitive" = 22,
	"showing" = 23,
	"single-line" = 24,
	"stale" = 25,
	"transient" = 26,
	"vertical" = 27,
	"visible" = 28,
	"manages-descendants" = 29,
	"indeterminate" = 30,
	"truncated" = 31,
	"required" = 32,
	"last-defined" = 33)
storage.mode(AtkStateType) <- 'integer'
class(AtkStateType) <- 'enums' 

AtkTextAttribute<-c("invalid" = 0,
	"left-margin" = 1,
	"right-margin" = 2,
	"indent" = 3,
	"invisible" = 4,
	"editable" = 5,
	"pixels-above-lines" = 6,
	"pixels-below-lines" = 7,
	"pixels-inside-wrap" = 8,
	"bg-full-height" = 9,
	"rise" = 10,
	"underline" = 11,
	"strikethrough" = 12,
	"size" = 13,
	"scale" = 14,
	"weight" = 15,
	"language" = 16,
	"family-name" = 17,
	"bg-color" = 18,
	"fg-color" = 19,
	"bg-stipple" = 20,
	"fg-stipple" = 21,
	"wrap-mode" = 22,
	"direction" = 23,
	"justification" = 24,
	"stretch" = 25,
	"variant" = 26,
	"style" = 27,
	"last-defined" = 28)
storage.mode(AtkTextAttribute) <- 'integer'
class(AtkTextAttribute) <- 'enums' 

AtkTextClipType<-c("none" = 0,
	"min" = 1,
	"max" = 2,
	"both" = 3)
storage.mode(AtkTextClipType) <- 'integer'
class(AtkTextClipType) <- 'enums' 

AtkTextBoundary<-c("char" = 0,
	"word-start" = 1,
	"word-end" = 2,
	"sentence-start" = 3,
	"sentence-end" = 4,
	"line-start" = 5,
	"line-end" = 6)
storage.mode(AtkTextBoundary) <- 'integer'
class(AtkTextBoundary) <- 'enums' 

AtkKeyEventType<-c("press" = 0,
	"release" = 1,
	"last-defined" = 2)
storage.mode(AtkKeyEventType) <- 'integer'
class(AtkKeyEventType) <- 'enums' 

AtkCoordType<-c("screen" = 0,
	"window" = 1)
storage.mode(AtkCoordType) <- 'integer'
class(AtkCoordType) <- 'enums'

==> RGtk2_2.12.4.tar.gz: RGtk2/R/atkEnumDefs.R <==
AtkRole<-c("invalid" = 0,
	"accel-label" = 1,
	"alert" = 2,
	"animation" = 3,
	"arrow" = 4,
	"calendar" = 5,
	"canvas" = 6,
	"check-box" = 7,
	"check-menu-item" = 8,
	"color-chooser" = 9,
	"column-header" = 10,
	"combo-box" = 11,
	"date-editor" = 12,
	"desktop-icon" = 13,
	"desktop-frame" = 14,
	"dial" = 15,
	"dialog" = 16,
	"directory-pane" = 17,
	"drawing-area" = 18,
	"file-chooser" = 19,
	"filler" = 20,
	"font-chooser" = 21,
	"frame" = 22,
	"glass-pane" = 23,
	"html-container" = 24,
	"icon" = 25,
	"image" = 26,
	"internal-frame" = 27,
	"label" = 28,
	"layered-pane" = 29,
	"list" = 30,
	"list-item" = 31,
	"menu" = 32,
	"menu-bar" = 33,
	"menu-item" = 34,
	"option-pane" = 35,
	"page-tab" = 36,
	"page-tab-list" = 37,
	"panel" = 38,
	"password-text" = 39,
	"popup-menu" = 40,
	"progress-bar" = 41,
	"push-button" = 42,
	"radio-button" = 43,
	"radio-menu-item" = 44,
	"root-pane" = 45,
	"row-header" = 46,
	"scroll-bar" = 47,
	"scroll-pane" = 48,
	"separator" = 49,
	"slider" = 50,
	"split-pane" = 51,
	"spin-button" = 52,
	"statusbar" = 53,
	"table" = 54,
	"table-cell" = 55,
	"table-column-header" = 56,
	"table-row-header" = 57,
	"tear-off-menu-item" = 58,
	"terminal" = 59,
	"text" = 60,
	"toggle-button" = 61,
	"tool-bar" = 62,
	"tool-tip" = 63,
	"tree" = 64,
	"tree-table" = 65,
	"unknown" = 66,
	"viewport" = 67,
	"window" = 68,
	"header" = 69,
	"footer" = 70,
	"paragraph" = 71,
	"ruler" = 72,
	"application" = 73,
	"autocomplete" = 74,
	"editbar" = 75,
	"embedded" = 76,
	"form" = 77,
	"last-defined" = 78)
storage.mode(AtkRole) <- 'integer'
class(AtkRole) <- 'enums' 

AtkLayer<-c("invalid" = 0,
	"background" = 1,
	"canvas" = 2,
	"widget" = 3,
	"mdi" = 4,
	"popup" = 5,
	"overlay" = 6,
	"window" = 7)
storage.mode(AtkLayer) <- 'integer'
class(AtkLayer) <- 'enums' 

AtkRelationType<-c("null" = 0,
	"controlled-by" = 1,
	"controller-for" = 2,
	"label-for" = 3,
	"labelled-by" = 4,
	"member-of" = 5,
	"node-child-of" = 6,
	"flows-to" = 7,
	"flows-from" = 8,
	"subwindow-of" = 9,
	"embeds" = 10,
	"embedded-by" = 11,
	"popup-for" = 12,
	"parent-window-of" = 13,
	"description-for" = 14,
	"described-by" = 15,
	"last-defined" = 16)
storage.mode(AtkRelationType) <- 'integer'
class(AtkRelationType) <- 'enums' 

AtkStateType<-c("invalid" = 0,
	"active" = 1,
	"armed" = 2,
	"busy" = 3,
	"checked" = 4,
	"defunct" = 5,
	"editable" = 6,
	"enabled" = 7,
	"expandable" = 8,
	"expanded" = 9,
	"focusable" = 10,
	"focused" = 11,
	"horizontal" = 12,
	"iconified" = 13,
	"modal" = 14,
	"multi-line" = 15,
	"multiselectable" = 16,
	"opaque" = 17,
	"pressed" = 18,
	"resizable" = 19,
	"selectable" = 20,
	"selected" = 21,
	"sensitive" = 22,
	"showing" = 23,
	"single-line" = 24,
	"stale" = 25,
	"transient" = 26,
	"vertical" = 27,
	"visible" = 28,
	"manages-descendants" = 29,
	"indeterminate" = 30,
	"truncated" = 31,
	"required" = 32,
	"animated" = 33,
	"visited" = 34,
	"default" = 35,
	"last-defined" = 36)
storage.mode(AtkStateType) <- 'integer'
class(AtkStateType) <- 'enums' 

AtkTextAttribute<-c("invalid" = 0,
	"left-margin" = 1,
	"right-margin" = 2,
	"indent" = 3,
	"invisible" = 4,
	"editable" = 5,
	"pixels-above-lines" = 6,
	"pixels-below-lines" = 7,
	"pixels-inside-wrap" = 8,
	"bg-full-height" = 9,
	"rise" = 10,
	"underline" = 11,
	"strikethrough" = 12,
	"size" = 13,
	"scale" = 14,
	"weight" = 15,
	"language" = 16,
	"family-name" = 17,
	"bg-color" = 18,
	"fg-color" = 19,
	"bg-stipple" = 20,
	"fg-stipple" = 21,
	"wrap-mode" = 22,
	"direction" = 23,
	"justification" = 24,
	"stretch" = 25,
	"variant" = 26,
	"style" = 27,
	"last-defined" = 28)
storage.mode(AtkTextAttribute) <- 'integer'
class(AtkTextAttribute) <- 'enums' 

AtkTextClipType<-c("none" = 0,
	"min" = 1,
	"max" = 2,
	"both" = 3)
storage.mode(AtkTextClipType) <- 'integer'
class(AtkTextClipType) <- 'enums' 

AtkTextBoundary<-c("char" = 0,
	"word-start" = 1,
	"word-end" = 2,
	"sentence-start" = 3,
	"sentence-end" = 4,
	"line-start" = 5,
	"line-end" = 6)
storage.mode(AtkTextBoundary) <- 'integer'
class(AtkTextBoundary) <- 'enums' 

AtkKeyEventType<-c("press" = 0,
	"release" = 1,
	"last-defined" = 2)
storage.mode(AtkKeyEventType) <- 'integer'
class(AtkKeyEventType) <- 'enums' 

AtkCoordType<-c("screen" = 0,
	"window" = 1)
storage.mode(AtkCoordType) <- 'integer'
class(AtkCoordType) <- 'enums'
